==> bonita-java-client-1.0.0-sources.jar: org/bonitasoft/web/client/model/TenantPauseRequest.java <==
/** 
 * Copyright (C) 2022 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2.0 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.bonitasoft.web.client.model;

import java.io.Serializable;
import java.util.Objects;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

/**
 * TenantPauseRequest
 */
@JsonPropertyOrder({
        TenantPauseRequest.JSON_PROPERTY_PAUSED
})
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen")
public class TenantPauseRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PAUSED = "paused";
    private String paused;

    public TenantPauseRequest() {
    }

    public TenantPauseRequest paused(String paused) {

        this.paused = paused;
        return this;
    }

    /**
     * wether the system tenant should be paused or not
     * 
     * @return paused
     **/
    @jakarta.annotation.Nullable
    @JsonProperty(JSON_PROPERTY_PAUSED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPaused() {
        return paused;
    }

    @JsonProperty(JSON_PROPERTY_PAUSED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPaused(String paused) {
        this.paused = paused;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TenantPauseRequest tenantPauseRequest = (TenantPauseRequest) o;
        return Objects.equals(this.paused, tenantPauseRequest.paused);
    }

    @Override
    public int hashCode() {
        return Objects.hash(paused);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TenantPauseRequest {\n");
        sb.append("    paused: ").append(toIndentedString(paused)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> bonita-java-client-2.0.1-sources.jar: org/bonitasoft/web/client/model/TenantPauseRequest.java <==
/** 
 * Copyright (C) 2024-2023 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2.0 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.bonitasoft.web.client.model;

import java.io.Serializable;
import java.util.Objects;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

/**
 * TenantPauseRequest
 */
@JsonPropertyOrder({
        TenantPauseRequest.JSON_PROPERTY_PAUSED
})
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", comments = "Generator version: 7.8.0")
public class TenantPauseRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PAUSED = "paused";
    private String paused;

    public TenantPauseRequest() {
    }

    public TenantPauseRequest paused(String paused) {

        this.paused = paused;
        return this;
    }

    /**
     * wether the system tenant should be paused or not
     * 
     * @return paused
     */
    @jakarta.annotation.Nullable
    @JsonProperty(JSON_PROPERTY_PAUSED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPaused() {
        return paused;
    }

    @JsonProperty(JSON_PROPERTY_PAUSED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPaused(String paused) {
        this.paused = paused;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TenantPauseRequest tenantPauseRequest = (TenantPauseRequest) o;
        return Objects.equals(this.paused, tenantPauseRequest.paused);
    }

    @Override
    public int hashCode() {
        return Objects.hash(paused);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TenantPauseRequest {\n");
        sb.append("    paused: ").append(toIndentedString(paused)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
